Learn R Programming

qbr (version 1.4.0)

create_app: Create an app

Description

Create a new Quickbase app

Usage

create_app(
  subdomain,
  auth,
  name,
  agent = NULL,
  assign_token = FALSE,
  description = NULL,
  security_properties = NULL,
  variables = NULL
)

Value

A nested list which includes the resulting app ID.

Arguments

subdomain

Character vector with one element. Found at the beginning of the Quickbase URL. Realm specific.

auth

Character vector with one element. The Quickbase authentication scheme you are using to authenticate the request (e.g., user token).

name

Character. Name of the app.

agent

Optional. Character vector with one element. Describes user/agent making API call.

assign_token

Logical, defaults to false. If true, the created app is assigned to the user token used in the auth argument.

description

Vector of length 1. Describes the app created.

security_properties

Named list of security settings for the app. Configurable security properties currently include the following logicals: allowClone, allowExport, enableAppTokens, hideFromPubic, mustBeRealmApproved, and useIPFilter

variables

Named character vector of length 10 or less. The name and value of each element will be used to name a variable and assign it a value in the app created.

Examples

Run this code
if (FALSE) {
create_app(
  subdomain = "abc",
  auth = keyring::key_get("qb_example"),
  name = "My new app",
  variables = c(
    "Theme Color" = "#74489D",
    "App start" = "2026-09-01"
  ),
  security_properties = list(
    enableAppTokens = TRUE,
    hideFromPublic = TRUE,
  )
)
}

Run the code above in your browser using DataLab